# os-scrapy

[![Build Status](https://www.travis-ci.org/cfhamlet/os-scrapy.svg?branch=master)](https://www.travis-ci.org/cfhamlet/os-scrapy)
[![codecov](https://codecov.io/gh/cfhamlet/os-scrapy/branch/master/graph/badge.svg)](https://codecov.io/gh/cfhamlet/os-scrapy)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/os-scrapy.svg)](https://pypi.python.org/pypi/os-scrapy)
[![PyPI](https://img.shields.io/pypi/v/os-scrapy.svg)](https://pypi.python.org/pypi/os-scrapy)


Ozzy's Scrapy scaffold.

## Requirements

* Python 3.6+ (pypy3.6+)
* [Scrapy](https://github.com/scrapy/scrapy) 2.0+

## Install 

```
pip install os-scrapy
```

## Usage

### Command line

```
os-scrapy
```

## Unit Tests

```
tox
```

## License

MIT licensed.